@@ -13,7 +13,6 @@
 # limitations under the License.
 """Name/string resolution to structured messages or identifiers."""
 import email.message
-import logging
 import re
 import urllib.parse
 import urllib.request
@@ -21,10 +20,11 @@ import urllib.error
 
 from rdkit import Chem
 
+from ord_schema.logging import get_logger
 from ord_schema import message_helpers
 from ord_schema.proto import reaction_pb2
 
-logger = logging.getLogger()
+logger = get_logger(__name__)
 
 _COMPOUND_STRUCTURAL_IDENTIFIERS = [
     reaction_pb2.CompoundIdentifier.SMILES,
